@@ -5,7 +5,7 @@
 ;; Keywords: multimedia
 ;; Homepage: https://gitlab.com/contrapunctus/sxiv.el
 ;; Package-Requires: ((dash "2.16.0") (emacs "25.1"))
-;; Version: 0.3.1
+;; Version: 0.3.3
 
 ;; This is free and unencumbered software released into the public domain.
 ;;
@@ -56,13 +56,17 @@ With no marked files, or if not in a Dired buffer, return nil."
 (defun sxiv-insert-subdirs (paths)
   "Insert subdirectories from PATHS into the current Dired buffer.
 Return PATHS unchanged."
-  (mapc (lambda (path)
-          ;; is the file a direct child? (i.e. exists in the current directory?)
-          (unless (and (file-exists-p (file-name-nondirectory path))
-                       (file-directory-p path))
-            (dired-insert-subdir (file-name-directory path))))
-        paths)
-  paths)
+  (cl-loop for path in paths
+    ;; If the file does not exist in the current directory...
+    unless (and (file-exists-p (file-name-nondirectory path))
+                ;; ;; ...I don't understand why this is here!
+                ;; ;; Why would there be a directory in the selected
+                ;; ;; files, seeing as one can't mark directories in
+                ;; ;; sxiv?
+                ;; (file-directory-p path)
+              )
+    do (dired-insert-subdir (file-name-directory path))
+    finally return paths))
 
 (defun sxiv-dired-mark-files (files)
   "Mark FILES in the current (dired) buffer."
@@ -103,51 +107,46 @@ the files listed."
                                    ;; REVIEW - also check if file is an image?
                                    (file-regular-p path-at-point))
                           (file-relative-name path-at-point)))
-         (paths         (cond ((sxiv-dired-marked-files-p)
-                               (dired-get-marked-files))
-                              ((derived-mode-p 'text-mode)
-                               (--> (buffer-substring-no-properties (point-min)
-                                                                    (point-max))
-                                    (split-string it "\n")))
-                              (t (directory-files default-directory))))
-         (paths         (--remove (or (equal it ".")
-                                      (equal it "..")
-                                      ;; Currently, this takes effect even
-                                      ;; when running from a text
-                                      ;; file...should that be the case?
-                                      (-find (lambda (exclude)
-                                               (string-match-p exclude it))
-                                             sxiv-exclude-strings))
-                                  paths))
+         (paths (cond ((sxiv-dired-marked-files-p)
+                       (dired-get-marked-files))
+                      ((derived-mode-p 'text-mode)
+                       (--> (buffer-substring-no-properties (point-min) (point-max))
+                            (split-string it "\n")))
+                      (t (directory-files default-directory))))
+         (paths (--remove (or (equal it ".")
+                              (equal it "..")
+                              ;; Currently, this takes effect even
+                              ;; when running from a text
+                              ;; file...should that be the case?
+                              (-find (lambda (exclude)
+                                       (string-match-p exclude it))
+                                     sxiv-exclude-strings))
+                          paths))
          ;; recurse with prefix arg, or if every path is a directory
-         (recurse       (or prefix
-                            (-every? #'file-directory-p paths)))
+         (recurse (or prefix (-every? #'file-directory-p paths)))
          ;; remove directories if not running recursively
-         (paths         (if recurse
-                            paths
-                          (seq-remove #'file-directory-p paths)))
+         (paths (if recurse paths (seq-remove #'file-directory-p paths)))
          (fn-at-point-index (when fn-at-point
                               (--find-index (equal fn-at-point it)
                                             paths)))
          (fn-at-point-index (when fn-at-point-index
                               (-> (1+ fn-at-point-index)
                                   (number-to-string))))
-         (recurse       (if recurse "-r" ""))
-         (proc          (progn
-                          (message "Running sxiv...")
-                          (make-process :name "sxiv"
-                                        :buffer "sxiv"
-                                        :command
-                                        (append '("sxiv")
-                                                sxiv-arguments
-                                                (when fn-at-point-index
-                                                  (list "-n" fn-at-point-index))
-                                                (list recurse "--")
-                                                paths)
-                                        :connection-type 'pipe
-                                        :stderr "sxiv-errors"))))
+         (recurse       (if recurse "-r" "")))
     (setq sxiv--directory default-directory)
-    (set-process-filter proc #'sxiv-filter)))
+    (message "Running sxiv...")
+    (make-process :name "sxiv"
+                  :buffer "sxiv"
+                  :command
+                  (append '("sxiv")
+                          sxiv-arguments
+                          (when fn-at-point-index
+                            (list "-n" fn-at-point-index))
+                          (list recurse "--")
+                          paths)
+                  :connection-type 'pipe
+                  :filter #'sxiv-filter
+                  :stderr "sxiv-errors")))
 
 ;; Local Variables:
 ;; nameless-current-name: "sxiv"
